Module fmt

Module fmt 

Structs

Arguments
This structure represents a safely precompiled version of a format string and its arguments. This cannot be generated at runtime because it cannot safely be done, so no constructors are given and the fields are private to prevent modification.
DebugList
A struct to help with fmt::Debug implementations.
DebugMap
A struct to help with fmt::Debug implementations.
DebugSet
A struct to help with fmt::Debug implementations.
DebugStruct
A struct to help with fmt::Debug implementations.
DebugTuple
A struct to help with fmt::Debug implementations.
Error
The error type which is returned from formatting a message into a stream.
Format
Display adapter returned by FmtIteratorExt::format.
FormatWith
Display adapter returned by FmtIteratorExt::format_with.
Formatter
Configuration for formatting.
FromFn
Display adapter returned by from_fn.
FormattingOptionsExperimental
Options for formatting.

Enums

Alignment
Possible alignments returned by Formatter::align
DebugAsHexExperimental
Specifies whether the Debug trait should use lower-/upper-case hexadecimal or normal integers.
SignExperimental
The signedness of a Formatter (or of a FormattingOptions).

Traits

Binary
b formatting.
Debug
? formatting.
Display
Format trait for an empty format, {}.
FmtIteratorExt
Iterator formatting helpers.
LowerExp
e formatting.
LowerHex
x formatting.
Octal
o formatting.
Pointer
p formatting.
UpperExp
E formatting.
UpperHex
X formatting.
Write
A trait for writing or formatting into Unicode-accepting buffers or streams.

Functions

formatNon-no_global_oom_handling
Takes an Arguments struct and returns the resulting formatted string.
from_fn
Creates a formatter from a function.
or_list
Returns list formatted as a comma-separated list with “or” before the last item.
write
Takes an output stream and an Arguments struct that can be precompiled with the format_args! macro.

Type Aliases

Result
The type returned by formatter methods.

Derive Macros

Debug
Derive macro generating an impl of the trait Debug.