Module hint

Functions

likelyExperimentalnightly
Hints to the compiler that branch condition is likely to be true. Returns the value passed to it.
unlikelyExperimentalnightly
Hints to the compiler that branch condition is likely to be false. Returns the value passed to it.