Index types. See ::oxc_index.
Macros
- define_
nonmax_ u32_ index_ type - Generate the boilerplate for a newtyped index struct using NonMaxU32.
This is a specialized version of
define_index_type!for use withNonMaxU32from thenonmaxcrate. - index_
box - A macro similar to the stdlib’s
vec![], but producing anBox<IndexSlice<I, [T]>>(That is, anIndexBox<I, [T]>). - index_
vec - A macro equivalent to the stdlib’s
vec![], but producing anIndexVec.
Structs
- Index
Slice - A slice that only accepts indices of a specific type. Note that the intended
usage is as
IndexSlice<I, [T]>. - Index
Vec - A Vec that only accepts indices of a specific type.
- NonMax
U32 - An integer that is known not to equal its maximum value.
Traits
- Idx
- Represents a wrapped value convertible to and from a
usize. - IdxRange
Bounds - This trait to function in API signatures where
Vec<T>or[T]useR: RangeBounds<usize>. There are blanket implementations for the basic range types incore::opsfor all Idx types. e.g.Range<I: Idx>,RangeFrom<I: Idx>,RangeTo<I: Idx>, etc all implement it. - IdxSlice
Index - This is the equivalent of the sealed
core::slice::SliceIndextrait. It cannot be overridden from user, code nor should it normally need use directly (Outside of trait bounds, I guess).
Type Aliases
- Index
Box IndexBox<I, [T]>: An alias for indexed boxed slice.