pub struct NonMaxU32(/* private fields */);Expand description
An integer that is known not to equal its maximum value.
Implementations
Sourceimpl NonMaxU32
impl NonMaxU32
Sourcepub const MAX: NonMaxU32
pub const MAX: NonMaxU32
Gets non-max with maximum possible value (which is maximum of the underlying primitive minus one)
Sourcepub const fn new(value: u32) -> Option<NonMaxU32>
pub const fn new(value: u32) -> Option<NonMaxU32>
Creates a new non-max if the given value is not the maximum value.
Sourcepub const unsafe fn new_unchecked(value: u32) -> NonMaxU32
pub const unsafe fn new_unchecked(value: u32) -> NonMaxU32
Creates a new non-max without checking the value.
Safety
The value must not equal the maximum representable value for the primitive type.