Structs
- Arguments
- This structure represents a safely precompiled version of a format string and its arguments. This cannot be generated at runtime because it cannot safely be done, so no constructors are given and the fields are private to prevent modification.
- Debug
List - A struct to help with
fmt::Debugimplementations. - Debug
Map - A struct to help with
fmt::Debugimplementations. - Debug
Set - A struct to help with
fmt::Debugimplementations. - Debug
Struct - A struct to help with
fmt::Debugimplementations. - Debug
Tuple - A struct to help with
fmt::Debugimplementations. - Error
- The error type which is returned from formatting a message into a stream.
- Format
- Display adapter returned by
FmtIteratorExt::format. - Format
With - Display adapter returned by
FmtIteratorExt::format_with. - Formatter
- Configuration for formatting.
- FromFn
- Display adapter returned by
from_fn. - Formatting
Options Experimental - Options for formatting.
Enums
- Alignment
- Possible alignments returned by
Formatter::align - Debug
AsHex Experimental - Specifies whether the
Debugtrait should use lower-/upper-case hexadecimal or normal integers. - Sign
Experimental - The signedness of a
Formatter(or of aFormattingOptions).
Traits
- Binary
bformatting.- Debug
?formatting.- Display
- Format trait for an empty format,
{}. - FmtIterator
Ext - Iterator formatting helpers.
- Lower
Exp eformatting.- Lower
Hex xformatting.- Octal
oformatting.- Pointer
pformatting.- Upper
Exp Eformatting.- Upper
Hex Xformatting.- Write
- A trait for writing or formatting into Unicode-accepting buffers or streams.
Functions
- format
Non- no_global_oom_handling - Takes an
Argumentsstruct and returns the resulting formatted string. - from_fn
- Creates a formatter from a function.
- or_list
- Returns
listformatted as a comma-separated list with “or” before the last item. - write
- Takes an output stream and an
Argumentsstruct that can be precompiled with theformat_args!macro.
Type Aliases
- Result
- The type returned by formatter methods.
Derive Macros
- Debug
- Derive macro generating an impl of the trait
Debug.