Module hint
Source - likelyExperimental
nightly - Hints to the compiler that branch condition is likely to be true.
Returns the value passed to it.
- unlikelyExperimental
nightly - Hints to the compiler that branch condition is likely to be false.
Returns the value passed to it.